@@ -1,23 +1,22 @@
-from .events import FetchEvent
-from tenacity import retry, wait, stop
-import tenacity
+from opal_common.fetcher.events import FetchEvent
+from opal_common.fetcher.logger import get_logger
+from tenacity import retry, stop, wait
 
-from .logger import get_logger
 logger = get_logger("opal.providers")
 
 
 class BaseFetchProvider:
-    """
-    Base class for data fetching providers.
-     - Override self._fetch_ to implement fetching
-     - call self.fetch() to retrive data (wrapped in retries and safe execution guards)
-     - override __aenter__ and __aexit__ for async context 
+    """Base class for data fetching providers.
+
+    - Override self._fetch_ to implement fetching
+    - call self.fetch() to retrieve data (wrapped in retries and safe execution guards)
+    - override __aenter__ and __aexit__ for async context
     """
 
     DEFAULT_RETRY_CONFIG = {
-        'wait': wait.wait_random_exponential(),
+        "wait": wait.wait_random_exponential(),
         "stop": stop.stop_after_attempt(200),
-        "reraise": True
+        "reraise": True,
     }
 
     def __init__(self, event: FetchEvent, retry_config=None) -> None:
@@ -29,11 +28,12 @@ class BaseFetchProvider:
         # convert the event as needed and save it
         self._event = self.parse_event(event)
         self._url = event.url
-        self._retry_config = retry_config if retry_config is not None else self.DEFAULT_RETRY_CONFIG
+        self._retry_config = (
+            retry_config if retry_config is not None else self.DEFAULT_RETRY_CONFIG
+        )
 
-    def parse_event(self, event:FetchEvent)->FetchEvent:
-        """
-        Parse the event (And config within it) into the right object type
+    def parse_event(self, event: FetchEvent) -> FetchEvent:
+        """Parse the event (And config within it) into the right object type.
 
         Args:
             event (FetchEvent): the event to be parsed
@@ -42,11 +42,10 @@ class BaseFetchProvider:
             FetchEvent: an event deriving from FetchEvent
         """
         return event
-        
 
     async def fetch(self):
-        """
-        Fetch and return data.
+        """Fetch and return data.
+
         Calls self._fetch_ with a retry mechanism
         """
         attempter = retry(**self._retry_config)(self._fetch_)
@@ -54,36 +53,32 @@ class BaseFetchProvider:
         return res
 
     async def process(self, data):
-        try: 
+        try:
             return await self._process_(data)
         except:
             logger.exception("Failed to process fetched data")
             raise
 
     async def __aenter__(self):
-        return self 
+        return self
 
     async def __aexit__(self, exc_type=None, exc_val=None, tb=None):
         pass
 
     async def _fetch_(self):
-        """
-        Internal fetch operation called by self.fetch()
-        Override this method to implement a new fetch provider
-        """
+        """Internal fetch operation called by self.fetch() Override this method
+        to implement a new fetch provider."""
         pass
 
     async def _process_(self, data):
         return data
 
-    def set_retry_config(self, retry_config:dict):
-        """ 
-        Set the configuration for retrying failed fetches
+    def set_retry_config(self, retry_config: dict):
+        """Set the configuration for retrying failed fetches.
+
         @see self.DEFAULT_RETRY_CONFIG
 
         Args:
             retry_config (dict): Tenacity retry config
         """
         self._retry_config = retry_config
-
-
