@@ -1,14 +1,16 @@
 import os
 import ssl
-
 from typing import Optional
 
 from opal_common.config import opal_common_config
 
+
 def get_custom_ssl_context() -> Optional[ssl.SSLContext]:
-    """
-    Potentially (if enabled), returns a custom ssl context that respect self-signed certificates.
-    More accurately, may return an ssl context that respects a local CA as a valid issuer.
+    """Potentially (if enabled), returns a custom ssl context that respect
+    self-signed certificates.
+
+    More accurately, may return an ssl context that respects a local CA
+    as a valid issuer.
     """
     if not opal_common_config.CLIENT_SELF_SIGNED_CERTIFICATES_ALLOWED:
         return None
@@ -18,11 +20,11 @@ def get_custom_ssl_context() -> Optional[ssl.SSLContext]:
     if ca_file is None:
         return None
 
-    if len(ca_file) == 0:
+    if not ca_file:
         return None
 
     ca_file_path = os.path.expanduser(ca_file)
     if not os.path.isfile(ca_file_path):
         return None
 
-    return ssl.create_default_context(cafile=ca_file_path)
\ No newline at end of file
+    return ssl.create_default_context(cafile=ca_file_path)
